# Quality Seal
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/quality-seal#introduction)
  * [Breaking of Quality Seal](https://help.sap.com/docs/leanix/ea/quality-seal#breaking-of-quality-seal)
  * [Quality Seal States](https://help.sap.com/docs/leanix/ea/quality-seal#quality-seal-states)
  * [Quality Seal States of New Fact Sheets](https://help.sap.com/docs/leanix/ea/quality-seal#quality-seal-states-of-new-fact-sheets)
  * [Approving Fact Sheet Quality](https://help.sap.com/docs/leanix/ea/quality-seal#approving-fact-sheet-quality)
  * [Enabling or Disabling the Quality Seal](https://help.sap.com/docs/leanix/ea/quality-seal#enabling-or-disabling-the-quality-seal)
  * [Notifications](https://help.sap.com/docs/leanix/ea/quality-seal#notifications)


Quality seal ensures data integrity by assigning approval responsibility to accountable and responsible subscribers of fact sheets. When broken, it prompts verification and approval of fact sheet information.
